diff --git a/osu.Game/Rulesets/Scoring/HealthProcessor.cs b/osu.Game/Rulesets/Scoring/HealthProcessor.cs
index 5e4e40b3bb..0f51560476 100644
--- a/osu.Game/Rulesets/Scoring/HealthProcessor.cs
+++ b/osu.Game/Rulesets/Scoring/HealthProcessor.cs
@@ -43,7 +43,7 @@ namespace osu.Game.Rulesets.Scoring
Health.Value += GetHealthIncreaseFor(result);
- if (meetsFailConditions(result))
+ if (meetsAnyFailCondition(result))
{
if (Failed?.Invoke() != false)
HasFailed = true;
@@ -70,10 +70,10 @@ namespace osu.Game.Rulesets.Scoring
protected virtual bool DefaultFailCondition => Precision.AlmostBigger(Health.MinValue, Health.Value);
///
/// Whether the current state of or the provided meets the fail conditions.
///
/// The judgement result.
- private bool meetsFailConditions(JudgementResult result)
+ private bool meetsAnyFailCondition(JudgementResult result)
{
if (DefaultFailCondition)
return true;
@@ -70,10 +70,10 @@ namespace osu.Game.Rulesets.Scoring
protected virtual bool DefaultFailCondition => Precision.AlmostBigger(Health.MinValue, Health.Value);
///
- /// Whether the current state of or the provided meets the fail conditions.
+ /// Whether the current state of or the provided meets any fail condition.
///
/// The judgement result.